package tech.powerjob.work.service.impl;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import tech.powerjob.work.domain.SysAuthInfoNew;
import tech.powerjob.work.domain.SysLoginfo;
import tech.powerjob.work.domain.SysUser;
import tech.powerjob.work.mapper.SysLoginfoMapper;
import tech.powerjob.work.service.SysAuthInfoNewService;
import tech.powerjob.work.service.SysLoginfoService;
import tech.powerjob.work.service.SysUserService;
import tech.powerjob.work.util.ReturnMsg;
import tech.powerjob.work.util.SignatureUtils;
import tech.powerjob.worker.core.processor.ProcessResult;

import javax.annotation.Resource;
import java.util.List;
import java.util.concurrent.CompletableFuture;

/**
* @author csdl
* @description 针对表【SYS_LOGINFO(系统日志)】的数据库操作Service实现
* @createDate 2024-08-01 10:31:15
*/
@Service
@Slf4j
public class SysLoginfoServiceImpl extends ServiceImpl<SysLoginfoMapper, SysLoginfo>
    implements SysLoginfoService {

    @Resource
    private SysUserService sysUserService;

    @Resource
    private SysAuthInfoNewService sysAuthInfoNewService;

    @Override
    public ProcessResult signature() {
        try {
            CompletableFuture<List<SysLoginfo>> future1 = CompletableFuture.supplyAsync(() -> this.list(Wrappers.<SysLoginfo>lambdaQuery().isNotNull(SysLoginfo::getB64Message).isNull(SysLoginfo::getB64MessageResult)));
            CompletableFuture<List<SysUser>> future2 = CompletableFuture.supplyAsync(() -> sysUserService.list(Wrappers.<SysUser>lambdaQuery().isNotNull(SysUser::getB64Message).isNull(SysUser::getB64MessageResult)));
            CompletableFuture<List<SysAuthInfoNew>> future3 = CompletableFuture.supplyAsync(() -> sysAuthInfoNewService.list(Wrappers.<SysAuthInfoNew>lambdaQuery().isNotNull(SysAuthInfoNew::getB64Message).isNull(SysAuthInfoNew::getB64MessageResult)));
            CompletableFuture.allOf(future1, future2, future3).join();
            List<SysLoginfo> sysLogInfos = future1.get();
            List<SysUser> sysUsers = future2.get();
            List<SysAuthInfoNew> sysAuthInfoNews = future3.get();
            for (SysLoginfo sysLogInfo : sysLogInfos) {
                sysLogInfo.setB64MessageResult(SignatureUtils.SignatureString(sysLogInfo.getB64Message()));
            }
            for (SysUser sysUser : sysUsers) {
                sysUser.setB64MessageResult(SignatureUtils.SignatureString(sysUser.getB64Message()));
            }
            for (SysAuthInfoNew sysAuthInfoNew : sysAuthInfoNews) {
                sysAuthInfoNew.setB64MessageResult(SignatureUtils.SignatureString(sysAuthInfoNew.getB64Message()));
            }
            this.saveOrUpdateBatch(sysLogInfos);
            sysUserService.saveOrUpdateBatch(sysUsers);
            sysAuthInfoNewService.saveOrUpdateBatch(sysAuthInfoNews);
            return ReturnMsg.returnMsg(true,"签名验签成功");
        }catch (Exception e){
            log.error("签名验签失败{}",e.getMessage());
            return ReturnMsg.returnMsg(false,"签名验签失败");
        }
    }
}




